@@ -260,10 +260,11 @@ class OpenApiWrapper:
         else:
             return {"type": "object"}
 
-    def _get_dataclass_description(self, spec: APISpec, schema: DataclassProtocol) -> dict:
+    def _get_dataclass_description(self, schema: DataclassProtocol) -> dict:
+        field_names = [field_.name for field_ in dataclasses.fields(schema) if field_.repr]
         return {"type": "object", "properties": {
-            field_.name: self._get_schema_description(field_.type)
-            for field_ in dataclasses.fields(schema) if field_.repr
+            key: self._get_schema_description(sub_schema)
+            for key, sub_schema in typing.get_type_hints(schema).items() if key in field_names
         }}
 
     @functools.cache
@@ -313,7 +314,7 @@ class OpenApiWrapper:
     def _add_dataclass_to_spec(self, spec: APISpec, schema: DataclassProtocol) -> None:
         logger.debug(f'_add_dataclass_to_spec: {schema}')
         assert dataclasses.is_dataclass(schema)
-        description = self._get_dataclass_description(spec, schema)
+        description = self._get_dataclass_description(schema)
         name = self.dataclass_type_to_name.get(schema, f"schema_{schema.__name__}")
         spec.components.schema(component_id=name, component=description)
 
